summaryrefslogtreecommitdiffstats
path: root/net/test
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-17 16:34:35 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-17 16:34:35 +0000
commit5b9a188a7cfdc6a59a90d9c7c57bf7c3c821a003 (patch)
tree48170636d199db3608a994a555aefd76a0b2d45b /net/test
parente198fbbc406356cf83f0d800c89066fac3bcc82a (diff)
downloadchromium_src-5b9a188a7cfdc6a59a90d9c7c57bf7c3c821a003.zip
chromium_src-5b9a188a7cfdc6a59a90d9c7c57bf7c3c821a003.tar.gz
chromium_src-5b9a188a7cfdc6a59a90d9c7c57bf7c3c821a003.tar.bz2
net: update certse.pem with new certs for tests.
The certse.pem certificate was revoked by Symantec and the tests depending on it were disabled in r211396. I've found the longest-lived certificates that I can to replace them. (And, this time, it's not EV so hopefully revocation checks don't kick in anyway.) BUG=259723 TBR=rsleevi Review URL: https://codereview.chromium.org/18323023 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@212058 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/test')
-rw-r--r--net/test/test_certificate_data.h30
1 files changed, 13 insertions, 17 deletions
diff --git a/net/test/test_certificate_data.h b/net/test/test_certificate_data.h
index 2953273..c9e29d4 100644
--- a/net/test/test_certificate_data.h
+++ b/net/test/test_certificate_data.h
@@ -9,26 +9,22 @@ static const char kNistSPKIHash[] =
"\x15\x60\xde\x65\x4e\x03\x9f\xd0\x08\x82"
"\xa9\x6a\xc4\x65\x8e\x6f\x92\x06\x84\x35";
// kCertSESPKIs contains the SHA1 hashes of the SPKIs of the certse.pem
// certificate chain, in order.
-static const char kCertSESPKIs[3][21] = {
- "\x3f\x6c\xf3\xf1\xc9\xdf\xb6\x63\xa8\x05"
- "\x44\x75\x9a\xac\x21\x4a\x74\xb2\xa5\xa4",
- "\xae\x4a\xd7\xf9\xb3\x80\xe1\x12\x93\x32"
- "\xbb\x52\xde\x5a\x09\x0c\x52\x1b\x33\xd0",
- "\xb1\x81\x08\x1a\x19\xa4\xc0\x94\x1f\xfa"
- "\xe8\x95\x28\xc1\x24\xc9\x9b\x34\xac\xc7",
+static const char kSatvedaSPKIs[2][21] = {
+ "\xd6\x2d\x7a\x12\x02\x7f\x9b\x8e\x4f\x2b"
+ "\x07\xc5\xfb\xf9\x2a\x2e\x9a\xcc\x0e\xe3",
+ "\xba\x2e\xb5\xa8\x3e\x13\x23\xd9\x53\x4b"
+ "\x5e\x65\xbc\xe7\xa3\x13\x5d\xd0\xa9\x96",
};
-// kCertSESPKIsSHA256 contains the SHA256 hashes of the SPKIs of the certse.pem
-// certificate chain, in order.
-static const char kCertSESPKIsSHA256[3][33] = {
- "\x32\xa4\x69\x36\xf0\xae\x10\x71\xe1\x97\xb6\xf8\xf8\x77\x2e\x2a"
- "\x4e\x3e\xca\x80\xb9\x38\x8c\xfb\xcd\xf0\xf2\xd0\xfb\x67\x76\xe9",
- "\x39\x35\x7a\x39\x20\x03\x66\xb4\x2e\x14\xc2\x2d\x68\x17\x3e\xe5"
- "\x7b\xc8\xb4\xad\x4b\x8d\xe8\x9f\xcb\xfc\xaf\x22\xd8\x4d\x8e\xf3",
- "\x25\xb4\x1b\x50\x6e\x49\x30\x95\x28\x23\xa6\xeb\x9f\x1d\x31\xde"
- "\xf6\x45\xea\x38\xa5\xc6\xc6\xa9\x6d\x71\x95\x7e\x38\x4d\xf0\x58",
+// kSatvedaSPKIsSHA256 contains the SHA256 hashes of the SPKIs of the
+// satveda.pem certificate chain, in order.
+static const char kSatvedaSPKIsSHA256[2][33] = {
+ "\xb9\x42\xab\xf2\x08\x63\xef\x81\x70\x88\x45\xc4\x39\xa2\x6e\x9c"
+ "\x2f\x9a\xf9\xf4\xcb\x23\x61\xd4\x83\x97\x61\x6d\xf2\x5b\x27\xa8",
+ "\x32\xb6\x4b\x66\x72\x7a\x20\x63\xe4\x06\x6f\x3b\x95\x8c\xb0\xaa"
+ "\xee\x57\x6a\x5e\xce\xfd\x95\x33\x99\xbb\x88\x74\x73\x1d\x95\x87",
};
// Certificates for test data. They're obtained with:
@@ -9,26 +9,22 @@ static const char kNistSPKIHash[] =
"\x15\x60\xde\x65\x4e\x03\x9f\xd0\x08\x82"
"\xa9\x6a\xc4\x65\x8e\x6f\x92\x06\x84\x35";
-// kCertSESPKIs contains the SHA1 hashes of the SPKIs of the certse.pem
+// kSatvedaSPKIs contains the SHA1 hashes of the SPKIs of the satveda.pem
// certificate chain, in order.